.. pact documentation master file, created by
   sphinx-quickstart on Tue Oct 28 17:52:42 2014.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

pact |release|
==============

**pact** is a library implementing a general concept of promises/deferreds. It less strictly follows known standards such as A+, but rather aims to be practical for library or framework implementations.

Check out the :ref:`user_guide` to get started

Contents:

.. toctree::
   :maxdepth: 2

   user_guide
   api
   changelog



Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

